package
Version:
v1.0.4
Opens a new window with list of versions in this module.
Published: Oct 23, 2022
License: MIT
Opens a new window with license information.
Imports: 11
Opens a new window with list of imports.
Imported by: 1
Opens a new window with list of known importers.
Documentation
¶
type Bot struct {
OptoutCodes sync.Map
}
Bot basic logging bot
NewBot create new bot instance
Connect startup the logger and bot
Source Files
¶
Click to show internal directories.
Click to hide internal directories.